#include <stdlib.h>
#include <qtimer.h>
#include <qwt_plot_grid.h>
#include <qwt_plot_canvas.h>
#include "scrollzoomer.h"
#include "randomplot.h"

const unsigned int c_rangeMax = 1000;

RandomPlot::RandomPlot(QWidget *parent):
    IncrementalPlot(parent),
    d_timer(0),
    d_timerCount(0)
{
    setFrameStyle(QFrame::NoFrame);
    setLineWidth(0);
    setCanvasLineWidth(2);

    QwtPlotGrid *grid = new QwtPlotGrid;
    grid->setMajPen(QPen(Qt::gray, 0, Qt::DotLine));
    grid->attach(this);

    setCanvasBackground(QColor(29, 100, 141)); // nice blue

    setAxisScale(xBottom, 0, c_rangeMax);
    setAxisScale(yLeft, 0, c_rangeMax);

    for ( int i = 0; i < QwtPlot::axisCnt; i++ )
        setAxisLabelFormat(i, 'g', 8);

    replot();

    // enable zooming

    ScrollZoomer *zoomer = new ScrollZoomer(canvas());
    zoomer->setRubberBandPen(QPen(Qt::black, 0, Qt::DotLine));
    zoomer->setTrackerPen(QPen(Qt::black));

#if QT_VERSION >= 0x040000
#ifdef __GNUC__
#warning bad update regions for rubberbands with not solid pens
#endif

    // The dot lines make Qt4 to send the bounding rect of
    // the rubberband as update region to the canvas. So we
    // need to suppress flickering.

    canvas()->setPaintAttribute(QwtPlotCanvas::PaintPacked, true);
#endif

}

QSize RandomPlot::sizeHint() const
{
    return QSize(540,400);
}

void RandomPlot::appendPoint()
{
    double x = rand() % c_rangeMax;
    x += ( rand() % 100 ) / 100;

    double y = rand() % c_rangeMax;
    y += ( rand() % 100 ) / 100;

    appendData(x, y);

    if ( --d_timerCount <= 0 )
        stop();
}

void RandomPlot::append(int timeout, int count)
{
    if ( !d_timer )
    {
        d_timer = new QTimer(this);
        connect(d_timer, SIGNAL(timeout()), SLOT(appendPoint()));
    }

    d_timerCount = count;

    emit running(true);

    canvas()->setPaintAttribute(QwtPlotCanvas::PaintCached, false);
    d_timer->start(timeout);
}

void RandomPlot::stop()
{
    if ( d_timer )
    {
        d_timer->stop();
        emit running(false);
    }

    canvas()->setPaintAttribute(QwtPlotCanvas::PaintCached, true);
}

void RandomPlot::clear()
{
    removeData();
    replot();
}
