/* -*- mode: C++ ; c-file-style: "stroustrup" -*- *****************************
 * Qwt Widget Library
 * Copyright (C) 1997   Josef Wilgen
 * Copyright (C) 2002   Uwe Rathmann
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the Qwt License, Version 1.0
 *****************************************************************************/

#ifndef QWT_SCALE_WIDGET_H
#define QWT_SCALE_WIDGET_H

#include <qwidget.h>
#include <qfont.h>
#include <qcolor.h>
#include <qstring.h>

#include "qwt_global.h"
#include "qwt_scale_draw.h"

class QPainter;
class QwtScaleTransformation;
class QwtScaleDiv;
class QwtText;

/*!
  \brief A Widget which contains a scale

  This Widget can be used to decorate composite widgets with
  a scale.
*/

class QWT_EXPORT QwtScaleWidget : public QWidget
{
    Q_OBJECT 
    Q_ENUMS(Position)
    Q_PROPERTY( Position position READ position WRITE setPosition )
    Q_PROPERTY( QString title READ title WRITE setTitle )
    Q_PROPERTY( QFont titleFont READ titleFont WRITE setTitleFont )
    Q_PROPERTY( QColor titleColor READ titleColor WRITE setTitleColor )

public:
    /*! 
        Position of the scale
        \sa QwtScaleWidget::QwtScaleWidget
     */
    
    enum Position { Left, Right, Top, Bottom };

    explicit QwtScaleWidget(QWidget *parent = NULL);
    explicit QwtScaleWidget(Position, QWidget *parent = NULL);
    virtual ~QwtScaleWidget();

    void setTitle(const QString &title);
    const QString title() const;

    void setTitleColor(const QColor &c);
    const QColor titleColor() const;

    void setTitleFont(const QFont &f);
    const QFont titleFont() const;

    void setTitleFlags(int flags);
    int titleFlags() const;

    void setBorderDist(int start, int end);
    int startBorderDist() const;
    int endBorderDist() const;
    void minBorderDist(int &start, int &end) const;

    void setBaselineDist(int bd);
    int baseLineDist() const;

    void setTitleDist(int td);
    int titleDist() const;

    void setScaleDiv(const QwtScaleTransformation&, const QwtScaleDiv &sd);
    void setScaleDraw(QwtScaleDraw *);
    const QwtScaleDraw *scaleDraw() const;

    void setLabelFormat(char f, int prec, int fieldWidth);
    void labelFormat(char &f, int &prec, int &fieldWidth) const;

    void setLabelFlags(int flags);
    void setLabelRotation(double rotation);

    virtual QSize sizeHint() const;
    virtual QSize minimumSizeHint() const;

    int titleHeightForWidth(int width) const;
    int dimForLength(int length, const QFont &scaleFont) const;

    void drawTitle(QPainter *painter, QwtScaleDraw::Orientation o,
        const QRect &rect) const;
        
    void setPosition(Position o);
    Position position() const;

protected:
    void draw(QPainter *p) const;
    void paintEvent(QPaintEvent *e);
    void resizeEvent(QResizeEvent *e);
    void scaleChange();
    void fontChange(const QFont &oldfont);
    void layoutScale( bool update = true );

private:
    void initScale(Position);

    class PrivateData;
    PrivateData *d_data;
};

#endif
