#ifndef ArchDefs_H
#define ArchDefs_H

#ifdef __GNUC__
#define PACKED __attribute__((packed))
#else
#error Only GNU C compiler is supported for now!
#endif

#include <limits.h>

typedef unsigned char u8;
typedef signed char s8;
typedef unsigned short u16;
typedef signed short s16;
#if UINT_MAX == 4294967295
typedef unsigned int u32;
typedef signed int s32;
#else
#error Architecture defs need tweaking as UINT_MAX is not the expected size.
#endif

#if ULONG_MAX == 4294967295
typedef unsigned long long u64;
typedef signed long long s64;
#elif ULONG_MAX > 4294967295
typedef unsigned long u64;
typedef signed long s64;
#else
#error Architecture defs need tweaking as ULONG_MAX is not the expected size.
#endif

#ifdef __cplusplus
extern "C" {
#endif

  static inline int is_little_endian(void) 
  {
    const u16 t = 0x5678;
    const u8 *p = (const u8 *)&t;
    return p[0] == 0x78;
  }

  /// swabs bytes to make an 32 bit int into little endian.  On LE arches this is a noop
  static inline void dw_to_le(void *v) 
  {
    if (!is_little_endian()) {
      u8 *p = (u8 *)v;
      u8 tmp = p[0];
      p[0] = p[3];
      p[3] = tmp;
      tmp = p[1];
      p[1] = p[2];
      p[2] = tmp;
    }
  }

  /// swabs bytes to make an 16 bit int into little endian.  On LE arches this is a noop
  static inline void w_to_le(void *v) 
  {
    if (!is_little_endian()) {
      u8 *p = (u8 *)v;
      u8 tmp = p[0];
      p[0] = p[1];
      p[1] = tmp;
    }
  }

  /// the inverse of dw_to_le -- on le arches this does nothing
  static inline void le_to_dw(void *v)   { dw_to_le(v); }
  /// the inverse of w_to_le -- on le arches this does nothing
  static inline void le_to_w(void *v)   { w_to_le(v); }
    

#ifdef __cplusplus
}
#endif

#endif
