#ifndef ComediDevice_H
#define ComediDevice_H

#define CD_STRMAX 64

#include "ArchDefs.h"
#include "CID.h"

typedef u32 Sample_t;

#ifdef __cplusplus
extern "C" {
#endif

  /* same thing as the struct in userspace comedilib */
  struct ComediRange 
  {
    double min;
    double max;
    u32 id; /* range id */
#ifdef __cplusplus
    ComediRange() : min(0), max(0), id(0) { }
#endif    
  } PACKED;

#ifdef __cplusplus
} // end extern "C"

template<class CR> void CR_From_comedi_range(ComediRange & r,
                                             const CR &cr, unsigned id = 0) 
{
      r.min = cr.min;
      r.max = cr.max;
      r.id = id;
      //if (cr.unit == 1) { r.min /= 1000.0; r.max /= 1000.0; }
}

template<class CR> CR CR_To_comedi_range(const ComediRange & r)
{
      CR ret;
      ret.min = r.min;
      ret.max = r.max;
      ret.unit = 0;
      return ret;
}

// re-begin extern "C"
extern "C" {
#endif
  
#ifndef __cplusplus
  typedef struct ComediRange ComediRange;
#endif

  struct ComediSubDevice
  {
    u32 minor; /* the minor this subdev belongs to */
    u32 id; /* subdev id */
    u32 type;
    u32 nChans;
    /* note: assumption is that maxdata and range info is *not* chan-specific!*/
    u32 maxdata;
    u32 nRanges; /* number of ranges for this channel */
    ComediRange range[MAX_RANGES];

    enum Type {
      Unused = 0, AI, AO, DI, DO, DIO, Counter, Timer, Memory, Calib, Proc, 
      Serial
    };

    enum DIOConfig {  Input = 0, Output = 1   };
    
  } PACKED;

#ifndef __cplusplus
typedef struct ComediSubDevice ComediSubDevice
#endif

  struct ComediDevice
  {
    u32 minor; /* /dev/comediXX, basically */
    char driverName[CD_STRMAX];
    char boardName [CD_STRMAX]; 
    u32 versionCode;
    u32 nSubdevs;
    ComediSubDevice subdev[MAX_SUBDEVS];
  } PACKED;

  // convert comedidevice structs from our protocol-order (Little-Endian) to machine order
  extern void comediDeviceFromLE(struct ComediDevice *, unsigned n_devices);
  // convert comedidevice structs from machine order to to our protocol-order (Little-Endian)
  extern void comediDeviceToLE(struct ComediDevice *, unsigned n_devices);
  
  // convert a single sample from our protocol order to machine order
  static inline void sampleFromLE(Sample_t *s) { le_to_dw(s); }
  // convert a single sample from machine order to our protocol order
  static inline void sampleToLE(Sample_t *s) { dw_to_le(s); }

#ifndef __cplusplus
  typedef struct ComediDevice ComediDevice;
#endif

#ifdef __cplusplus
} // extern "C"
#endif

#endif
